==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.DNSSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.DNSSpec,io.fabric8.openshift.api.model.operator.v1.DNSSpecBuilder>{
  public DNSSpecBuilder() {
    this(false);
  }
  public DNSSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSSpec(), validationEnabled);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSSpec(), validationEnabled);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSSpec instance) {
    this(fluent, instance, false);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNodePlacement(instance.getNodePlacement()); 
    fluent.withServers(instance.getServers()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpec instance) {
    this(instance,false);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNodePlacement(instance.getNodePlacement()); 
    this.withServers(instance.getServers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.DNSSpec build() {
    DNSSpec buildable = new DNSSpec(fluent.getNodePlacement(),fluent.getServers());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSSpecBuilder that = (DNSSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.DNSSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.DNSSpec,io.fabric8.openshift.api.model.operator.v1.DNSSpecBuilder>{
  public DNSSpecBuilder() {
    this(false);
  }
  public DNSSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSSpec(), validationEnabled);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSSpec(), validationEnabled);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSSpec instance) {
    this(fluent, instance, false);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.DNSSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withNodePlacement(instance.getNodePlacement()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withServers(instance.getServers()); 
    fluent.withUpstreamResolvers(instance.getUpstreamResolvers()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpec instance) {
    this(instance,false);
  }
  public DNSSpecBuilder(io.fabric8.openshift.api.model.operator.v1.DNSSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withNodePlacement(instance.getNodePlacement()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withServers(instance.getServers()); 
    this.withUpstreamResolvers(instance.getUpstreamResolvers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.DNSSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.DNSSpec build() {
    DNSSpec buildable = new DNSSpec(fluent.getLogLevel(),fluent.getManagementState(),fluent.getNodePlacement(),fluent.getOperatorLogLevel(),fluent.getServers(),fluent.getUpstreamResolvers());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSSpecBuilder that = (DNSSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
